A value drawn from a parameter sweep across evenly spaced values within the half-open interval [start,stop) as in numpy.arange(start,stop,step). The value drawn from the sequence is determined by taking the current run number modulo the number of values in the sequence and using that as an index into the sequence.
* "Start" - Start of the interval
* "Stop" - End of the interval
* "Step" - Spacing between values